@@ -3,8 +3,7 @@ from django.db import models
 from edc_model.models import BaseUuidModel
 from edc_utils import get_utcnow
 
-from edc_crf.crf_model_mixin import CrfModelMixin
-from edc_crf.crf_status_model_mixin import CrfStatusModelMixin
+from edc_crf.model_mixins import CrfModelMixin, CrfStatusModelMixin
 
 
 class Crf(CrfModelMixin, CrfStatusModelMixin, BaseUuidModel):
@@ -19,7 +18,7 @@ class Crf(CrfModelMixin, CrfStatusModelMixin, BaseUuidModel):
 
     f3 = models.CharField(max_length=50, null=True, blank=True)
 
-    class Meta(BaseUuidModel.Meta):
+    class Meta(CrfModelMixin.Meta, BaseUuidModel.Meta):
         pass
 
 
